##  Navigating to the Administration Area
Once you've set up your account with SAP LeanIX, you can navigate to the workspace administration area by selecting Administration in the user profile menu.
![Navigating to the Administration Area from the User Profile Menu](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d8a7b7a4410148b66f1c79bd138bb_LowRes.png)
Navigating to the Administration Area from the User Profile Menu
